@@ -19,10 +19,12 @@ _ROOT = os.path.abspath(os.path.dirname(__file__))
 def get_data(path):
     return os.path.join(_ROOT, path)
 
+logging.debug(_ROOT)
 # global section
 app = Flask(__name__, instance_relative_config=False)
 app.debug=True
 app.config.from_pyfile('instance/weatherservice-config.py')
+logging.debug(app.config)
 #app.config.from_envvar('WEATHERSERVICE-CONFIG', silent=True)
 # set the secret key.  keep this really secret:
 app.secret_key = 'A0Zr98j/3yX R~XHH!jmN]LWX/,?RT'
@@ -35,8 +37,8 @@ with open(get_data('etc/weather_map.json'), 'r') as map_data:
 wdata = {}
 
 # url end-point handlers
-@app.route('/getLiveWeatherRSS.aspx', methods=['POST','GET'])
-def getLiveWeatherRSS():
+@app.route('/old_getLiveWeatherRSS.aspx', methods=['POST','GET'])
+def old_getLiveWeatherRSS():
     global wdata
     mode='live'
     wdata = getWeatherData(app.config['QUERY_URL'])
@@ -53,6 +55,23 @@ def getLiveWeatherRSS():
     writeLog(mode)
     return render_template('getLiveWeatherRSS.html', obs = obs, date = date, hr = hr, iconLive = iconLive,  weburl = app.config['QUERY_URL'])
 
+@app.route('/getLiveWeatherRSS.aspx', methods=['POST','GET'])
+def getLiveWeatherRSS():
+#    global wdata
+    mode='live'
+    source_url = app.config['API_URL'] + app.config['API_KEY'] + app.config['API_CONDITIONS'] + 'pws:' + app.config['PWS'] + '.' +app.config['FORMAT']
+    r = requests.get(source_url)
+    logging.debug(r)
+    data = r.json()
+    logging.debug(data)
+    obs=data['current_observation']
+    iconKey = obs['icon']
+    icon.setdefault(iconKey,  10)
+    iconLive = icon [ iconKey ]
+    logging.debug('%s = %s' % (iconKey,  iconLive))
+    writeLog(mode)
+    return render_template('getLiveWeatherApi.html', obs = obs, iconLive = iconLive,  weburl = source_url)
+
 # forecast is called After liveWeather so we will reuse the wdata variable.
 @app.route('/old_getForecastRSS.aspx', methods=['POST','GET'])
 def old_getForecastRSS():
@@ -79,31 +98,31 @@ def old_getForecastRSS():
 def getForecastRSS():
     logging.info('Getting weather data via API')
     find_key = 'forecast'
-    source_url = app.config['API_URL'] + app.config['API_KEY'] + app.config['API_FORECAST']
-    logging.debug(source_url)
+    source_url = app.config['API_URL'] + app.config['API_KEY'] + app.config['API_FORECAST']+ 'pws:' + app.config['PWS'] + '.' +app.config['FORMAT']
+#    logging.debug(source_url)
     r = requests.get(source_url)
-    logging.debug(r)
+#    logging.debug(r)
     data = r.json()
     forecasts=[]
-    logging.debug(data)
+#    logging.debug(data)
     mode='forecast'
     loc=data['response']['features']
     logging.debug(loc)
     for i in range(0, 5):
         fc=data[mode]['simpleforecast']['forecastday'][i]
-        logging.debug(fc)
+ #       logging.debug(fc)
         # pop is probability of precipitation
         if fc['pop'] > 0:
             short_prediction = '%s%% %s' % (fc['pop'], fc['conditions'])
         else:
             short_prediction = fc['conditions']  
-        logging.debug(short_prediction)
+ #       logging.debug(short_prediction)
         fc['short_prediction'] = short_prediction            
         iconKey = fc['icon']
         icon.setdefault(iconKey,  10)
         forecasts.append(fc)    
      
-    logging.debug(forecasts)
+#    logging.debug(forecasts)
     now=datetime.now().strftime("%m/%d/%y %H:%M:%S %p")
     writeLog(mode)
     return render_template('getForecastApi.html', loc = loc, forecasts = forecasts, icon = icon, now = now)
